# Loren Williams, Georgia Tech
# pymol script for sugar pucker and glycosidic bond rotation

## Header: General Commands ##
# delete all objects and reset pymol
reinitialize
# set the background color to white
bg_color white
# make the background transparent for ray trace 
set ray_opaque_background, 0
# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2
# turn off shadows during ray trace
set ray_shadows, 0
# set the mouse mode for laptop.
config_mouse one_button
# get rid of double bonds and skinny bonds to H
set stick_h_scale, 1
set valence, 0
# high quality surfaces
set surface_quality, 2
## End of Header: General Commands ##


load files/2_p_endo.pdb
load files/3_p_endo.pdb
load files/g_anti.pdb
load files/g_syn.pdb

h_add
align 2_p_endo, 3_p_endo
align g_anti, 3_p_endo
align g_syn, 3_p_endo

hide everything, all
show stick, all

color wheat, name C1*+C2*+c3*+c4*+c5*
color wheat, name C1+C2+c3+c4+c5+c6+c7+c8
color gray90, name C1*+C2*+c3*+c4*+c5* and 3_p_endo
color gray90, name C1+C2+c3+c4+c5+c6+c7+c8 and 3_p_endo
color gray90, name C1*+C2*+c3*+c4*+c5* and g_syn
color gray90, name C1+C2+c3+c4+c5+c6+c7+c8 and g_syn


color blue, name N1+n2+N3++n6+n7+n9
color red, name O3*+O4*+O5*+O2+O4+O6
color cyan, name B
#remove name OP1+OP2+P

set stick_radius, 0.1


#---------------------------C 2' Endo (DNA)
label name B and 2_p_endo, "Base"
label name C2* and 2_p_endo, "C2' Endo"
label name O5* and 2_p_endo, "O5'"
label name O3* and 2_p_endo, "O3'"
label 2_p_endo and name O4*, "DNA"
set label_position, (0,3,0), 2_p_endo and name O4*


#---------------------------C 3' Endo (RNA)
label name B and 3_p_endo, "Base"
label name C3* and 3_p_endo, "C3' Endo"
label name O5* and 3_p_endo, "O5'"
label name O3* and 3_p_endo, "O3'"
label name O2* and 3_p_endo, "O2'"
label 3_p_endo and name O4*, "RNA"
set label_position, (0,3,0), 3_p_endo and name O4*


set label_size, -0.3
set label_color, black
disable all
enable 2_p_endo
#enable 3_p_endo

    
set_view (\
     0.915151000,    0.354605794,    0.191743523,\
    -0.150959447,   -0.139576688,    0.978643358,\
     0.373793542,   -0.924550235,   -0.074204937,\
     0.000000000,    0.000000000,  -14.178204536,\
    68.079605103,  118.372398376,   50.438701630,\
    11.178204536,   17.178203583,  -20.000000000 )
